@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 
-$CPAN::Reporter::VERSION = '0.99_11'; 
+$CPAN::Reporter::VERSION = '0.99_12'; 
 
 use Config;
 use CPAN ();
@@ -433,6 +433,7 @@ sub _expand_result {
     $result->{env_vars} = _env_report();
     $result->{special_vars} = _special_vars_report();
     $result->{toolchain_versions} = _toolchain_report( $result );
+    $result->{perl_version} = CPAN::Reporter::History::_format_perl_version();
     return;
 }
 
@@ -774,7 +775,7 @@ HERE
 
     'fail' => <<'HERE',
 Thank you for uploading your work to CPAN.  However, it appears that
-there were some problems testing your distribution.
+there were some problems with your distribution.
 HERE
 
     'unknown' => <<'HERE',
@@ -786,9 +787,9 @@ the results of the tests could not be parsed by CPAN::Reporter.
 HERE
 
     'na' => <<'HERE',
-Thank you for uploading your work to CPAN.  While attempting to test this
-distribution, the distribution signaled that support is not available either
-for this operating system or this version of Perl.  Nevertheless, any 
+Thank you for uploading your work to CPAN.  While attempting to build or test 
+this distribution, the distribution signaled that support is not available 
+either for this operating system or this version of Perl.  Nevertheless, any 
 diagnostic output produced is provided below for reference.
 HERE
     
@@ -801,20 +802,22 @@ sub _report_text {
     my $output = << "ENDREPORT";
 Dear $data->{author},
     
-This is a computer-generated test report for $data->{dist_name}, created
-automatically by CPAN::Reporter, version $CPAN::Reporter::VERSION, and sent to the CPAN 
-Testers mailing list.  If you have received this email directly, it is 
-because the person testing your distribution chose to send a copy to your 
-CPAN email address; there may be a delay before the official report is
-received and processed by CPAN Testers.
+This is a computer-generated report for $data->{dist_name}
+on $data->{perl_version}, created automatically by CPAN-Reporter-$CPAN::Reporter::VERSION and sent 
+to the CPAN Testers mailing list.  
+
+If you have received this email directly, it is because the person testing 
+your distribution chose to send a copy to your CPAN email address; there 
+may be a delay before the official report is received and processed 
+by CPAN Testers.
 
 $intro_para{ $data->{grade} }
 Sections of this report:
 
     * Tester comments
+    * Program output
     * Prerequisites
     * Environment and other context
-    * Test output
 
 ------------------------------
 TESTER COMMENTS
@@ -824,6 +827,13 @@ Additional comments from tester:
 
 [none provided]
 
+------------------------------
+PROGRAM OUTPUT
+------------------------------
+
+Output from '$data->{command}':
+
+$test_log
 ------------------------------
 PREREQUISITES
 ------------------------------
@@ -844,13 +854,6 @@ $data->{special_vars}
 Perl module toolchain versions installed:
 
 $data->{toolchain_versions}
-------------------------------
-TEST OUTPUT
-------------------------------
-
-Output from '$data->{command}':
-
-$test_log
 ENDREPORT
 
     return $output;
@@ -862,11 +865,10 @@ ENDREPORT
 
 sub _special_vars_report {
     my $special_vars = << "HERE";
-    Perl: \$^X = $^X
-    UID:  \$<  = $<
-    EUID: \$>  = $>
-    GID:  \$(  = $(
-    EGID: \$)  = $)
+    \$^X = $^X
+    \$UID/\$EUID = $< / $>
+    \$GID = $(
+    \$EGID = $)
 HERE
     if ( $^O eq 'MSWin32' && eval "require Win32" ) { ## no critic
         my @getosversion = Win32::GetOSVersion();
@@ -1191,8 +1193,7 @@ the overall quality and value of CPAN.
 One way individuals can contribute is to send a report for each module that
 they test or install.  CPAN::Reporter is an add-on for the CPAN.pm module to
 send the results of building and testing modules to the CPAN Testers project.
-Partial support for CPAN::Reporter is available in CPAN.pm as of version 1.88;
-full support is available in CPAN.pm as of version 1.91_53.
+Full support for CPAN::Reporter is available in CPAN.pm as of version 1.92.
 
 = GETTING STARTED
 
